#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

import requests
import json
from .database import Database
from prettytable import PrettyTable

state = [
    "在途",
    "揽件",
    "疑难",
    "签收",
    "退签",
    "派件",
    "退回"
]

class Controller():

    db = Database()
    session = requests.Session()

    def __init__(self):
        pass

    def list(self, nu="all"):
        query = self.db.get_item_query()
        ptable = PrettyTable(["运单号", "描述", "状态", "最后一次更新时间", "最后一次更新信息"])
        for item in query:
            ptable.add_row([item.nu, item.description, state[item.state], item.lastUpdateTime, item.lastUpdateInfo])
        print(ptable)

    def show_info(self, s_nu):
        nu = self.db.get_full_nu(s_nu)
        item = self.db.find_item(nu)
        print(item.description + "(" + nu + ")  " + state[item.state])
        if nu:
            query = self.db.get_info_query(nu)
            ptable = PrettyTable(["时间", "信息"])
            for info in query:
                ptable.add_row([info.time, info.context])
            print(ptable)
        else:
            print("单号不存在")

    def get_com_code(self, nu):
        url = "http://www.kuaidi100.com/autonumber/autoComNum?text=" + nu
        data = self.session.get(url).text
        jsonData = json.loads(data)
        return jsonData["auto"][0]["comCode"]

    def new_item(self, nu, des=None):
        try:
            if not self.db.has_item(nu):
                com_code = self.get_com_code(nu)
                if not des:
                    des = com_code + "快递"
                url = "http://www.kuaidi100.com/query?type=" + com_code + "&postid=" + nu;
                data = self.session.get(url).text
                jsonData = json.loads(data)
                status = jsonData["status"]
                state_code = int(jsonData["state"])
                data = jsonData["data"]
                for info in data:
                    time = info["time"]
                    context = info["context"]
                    time = time[:10] + " " + time[11:14] + time[15:]
                    self.db.insert_info(self.db.get_new_info_id(), nu, time, context)
                last_time = data[-1]["time"]
                last_time = last_time[:10] + " " + last_time[11:14] + last_time[15:]
                last_context = data[-1]["context"]
                self.db.insert_item(self.db.get_new_item_id(), nu, des, com_code, state_code, status, last_time, last_context)
            else:
                print("已存在")
        except KeyError:
            self.new_item(nu, des)

    def delete_item(self, nu):
        self.db.delete_item(nu)
        self.db.delete_info(nu)

    def update_all(self):
        try:
            for nu in self.db.get_all_nu():
                url = "http://www.kuaidi100.com/query?type=" + self.get_com_code(nu) + "&postid=" + nu;
                data = self.session.get(url).text
                jsonData = json.loads(data)
                status = jsonData["status"]
                state_code = int(jsonData["state"])
                data = jsonData["data"]
                for info in data:
                    time = info["time"]
                    context = info["context"]
                    time = time[:10] + " " + time[11:14] + time[15:]
                    self.db.insert_info(self.db.get_new_info_id(), nu, time, context)
                last_time = data[-1]["time"]
                last_time = last_time[:10] + " " + last_time[11:14] + last_time[15:]
                last_context = data[-1]["context"]
                self.db.update_item(nu, state_code, status, last_time, last_context)
        except KeyError:
            self.update_all()

if __name__ == "__main__":
    control = Controller()
    control.new_item("882967786411263996")
    control.new_item("610100445741")
    control.new_item("882909215041897319")
    control.update_all()



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

from sys import argv
from .controller import Controller


def main():
    controller = Controller()
    if len(argv) > 1:
        if argv[1] == "new":
            if len(argv) >= 4:
                controller.new_item(argv[2], argv[3])
            else:
                controller.new_item(argv[2])
        elif argv[1] == "list":
            if len(argv) == 3:
                controller.show_info(argv[2])
            else:
                controller.list()
        elif argv[1] == "update":
            controller.update_all()
        elif argv[1] == "delete":
            if len(argv) == 3:
                pass
            else:
                pass
        else:
            print("命令错误")
    else:
        print("233")

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# import sqlite3
import os
from sqlalchemy import create_engine, MetaData, Column, Integer, String
from sqlalchemy_utils import database_exists, create_database
from sqlalchemy.ext.declarative import declarative_base
# from sqlalchemy import engine
from sqlalchemy.orm import sessionmaker
from sqlalchemy.orm.exc import NoResultFound

Base = declarative_base()

class Item(Base):

    __tablename__ = "items"

    id = Column(Integer, primary_key=True)
    nu = Column(String)
    description = Column(String)
    comCode = Column(String)
    state = Column(Integer)
    status = Column(Integer)
    lastUpdateTime = Column(String, primary_key=True)
    lastUpdateInfo = Column(String)

    def __init__(self, id, nu, description, comCode, state, status, lastUpdateTime, lastUpdateInfo):
        self.id = id
        self.nu = nu
        self.description = description
        self.comCode = comCode
        self.state = state
        self.status = status
        self.lastUpdateTime = lastUpdateTime
        self.lastUpdateInfo = lastUpdateInfo

    def __repr__(self):
        return "<Item('%d','%s','%s','%s','%d','%d','%s','%s')"\
               % (self.id, self.nu, self.description, self.comCode, self.state,\
                  self.status, self.lastUpdateTime, self.lastUpdateInfo)


class Info(Base):

    __tablename__ = "infos"

    id = Column(Integer, primary_key=True)
    nu = Column(String)
    time = Column(String)
    context = Column(String)

    def __init__(self, id, nu, time, context):
        self.nu = nu
        self.time = time
        self.context = context

    def __repr__(self):
        return "<Info(time='%s',context='%s')" % (self.time, self.context)

class Database:

    items_table = Item.__table__
    metadata = Base.metadata
    engine = ""
    db_location = ""
    db_name = ""
    session = ""
    infos = []

    def __init__(self, db_name=".items.db"):
        self.db_name = db_name
        self.db_location = "sqlite:///" + os.path.expanduser("~") +"/" + db_name
        self.engine = create_engine(self.db_location, echo=False)
        self.metadata = MetaData(self.engine)
        Session = sessionmaker(bind=self.engine)
        self.session = Session()
        self.items_table = Item.__table__
        if not database_exists(self.db_location):
            create_database(self.engine.url)
        Base.metadata.create_all(self.engine)

    def get_all_nu(self):
        return [item.nu for item in self.session.query(Item)]

    def get_full_nu(self, short_nu):
        for nu in self.get_all_nu():
            if nu[:len(short_nu)] == short_nu:
                return nu
        return None

    def has_item(self, nu):
        query = self.session.query(Item).filter(Item.nu == nu)
        return query.count() > 0

    def insert_item(self, id, nu, description, comCode, state, status, lastUpdateTime, lastUpdateInfo):
        query = self.session.query(Item).filter(Item.nu == nu);
        if query.count() == 0:
            self.session.add(Item(id, nu, description, comCode, state, status, lastUpdateTime, lastUpdateInfo))
            self.session.commit()

    def insert_info(self, id, nu, time, context):
        query = self.session.query(Info).filter(Info.time == time);
        if query.count() == 0:
            self.session.add(Info(id, nu, time, context))
            self.session.commit()

    def get_new_item_id(self):
        query =   self.session.query(Item)\
                                    .order_by(Item.id)
        if (query.count() > 0):
            return query[-1].id + 1
        else:
            return 0

    def get_new_info_id(self):
        query =   self.session.query(Info)\
                                    .order_by(Info.id)
        if (query.count() > 0):
            return query[-1].id + 1
        else:
            return 0

    def find_item(self, nu):
        try:
            item = self.session.query(Item)\
                       .filter(Item.nu == nu)\
                       .one()
            return item
        except NoResultFound:
            print("无法找到")

    def update_item(self, nu, state, status, lastUpdateTime, lastUpdateInfo):
        try:
            item = self.session.query(Item)\
                       .filter(Item.nu == nu)\
                       .one()
            item.state = state
            item.status = status
            item.lastUpdateTime = lastUpdateTime
            item.lastUpdateInfo = lastUpdateInfo
            self.session.commit()
        except NoResultFound:
            print("无法找到")

    def delete_item(self, nu):
        try:
            item = self.session.query(Item)\
                       .filter(Item.nu == nu)\
                       .one()
            self.session.delete(item)
            self.session.commit()
        except NoResultFound:
            print("无法找到")

    def delete_info(self, nu):
        try:
            query = self.session.query(Info)\
                       .filter(Info.nu == nu)
            for info in query:
                self.session.delete(info)
            self.session.commit()
        except NoResultFound:
            print("无法找到")

    def get_item_query(self):
        return self.session.query(Item)

    def get_info_query(self, nu):
        return self.session.query(Info).filter(Info.nu == nu)

    def display(self):
        for instance in self.session.query(Item)\
                                    .order_by(Item.id):
            print(instance)

if __name__ == "__main__":
    db = Database()
    print(db.get_all_nu())



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_
from setuptools import setup, find_packages

VERSION = '0.1.1'

# with open('README.md') as f:
    # long_description = f.read()

setup(
      name='CryDeer', # 文件名
      version=VERSION, # 版本(每次更新上传Pypi需要修改)
      description="a command line express package helper",
      # long_description=long_description, # 放README.md文件,方便在Pypi页展示
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='python express package helper', # 关键字
      author='vimsucks', # 用户名
      author_email='reg@vimsucks.com', # 邮箱
      url='https://github.com/vimsucks/CryDeer', # github上的地址,别的地址也可以
      license='GPLv3', # 遵循的协议
      packages=find_packages(), # 发布的包名
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'requests',
          'prettytable',
          'sqlalchemy',
          'sqlalchemy-utils',
      ], # 满足的依赖
      entry_points={
        'console_scripts':[
            'crydeer = CryDeer.crydeer:main'
        ]
      },
)
